A library for Cargo build scripts to build and link a Cabal foreign library to Rust crates. The crate calls out to Cabal and GHC; all necesssary Haskell dependencies must be installed and managed separately.
Everything is a work-in-progress!
Example
For a basic usage example, see examples/basic.
Structs
- A builder for a Cabal library.
- A handler for a library built by Cabal.
Enums
- An error that occurs when generating bindings.
- Type for errors that may occur.
- An error that occurs when invoking
cabalorghc-pkg. - The version of the Haskell runtime library.
Type Aliases
- Generated Rust bindings for the Haskell library.
- Alias for Result.